@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 import argparse
-from sarscov2_meta_extract import convertor
+from sarscov2metaextract import convertor
 
 def main():
 	parser = argparse.ArgumentParser(description='Metadata extractor for SARS-CoV-2 selection analysis pipeline in Galaxy')
@@ -8,7 +8,7 @@ def main():
 	parser.add_argument('-m', '--metadata', dest='metadata', action='store', help='Metadata source (Use "ncbi" if using NCBI SARS-CoV-2 data, otherwise supply tabular file of the correct format)', required=True)
 	args = parser.parse_args()
 
-	convertor(args.alingment, args.metadata)
+	convertor(args.alignment, args.metadata)
 
 if __name__ == '__main__':
     exit(main())
\ No newline at end of file
